from django_global_log.models import DjangoGlobalLog


def get_ip(request):
    if request.META.get("HTTP_X_REAL_IP"):
        return request.META.get("HTTP_X_REAL_IP")
    if request.META.get("HTTP_X_FORWARDED_FOR"):
        return request.META.get("HTTP_X_FORWARDED_FOR").replace(" ", "").split(",")[0]
    return request.META.get("REMOTE_ADDR")


class SaveLogHandler:
    def __init__(self, data):
        self.data = data

    def __call__(self, *args, **kwargs):
        DjangoGlobalLog.objects.create(**self.data)


class GlobalLogExtraFuncMixin:
    def __init__(self, request, response):
        self.request = request
        self.response = response

    def __call__(self, *args, **kwargs):
        raise NotImplementedError



# Generated by Django 4.0.2 on 2022-03-20 16:57

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("django_global_log", "0001_initial"),
    ]

    operations = [
        migrations.AddField(
            model_name="djangogloballog",
            name="method",
            field=models.CharField(
                blank=True, max_length=64, null=True, verbose_name="请求方法"
            ),
        ),
    ]
